@@ -1,15 +1,17 @@
 """A collection of configurations to interact with dbt-core."""
 from __future__ import annotations
 
+import argparse
 import dataclasses
 import json
 import os
 import pickle
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Optional, Type, Union
+from typing import Any, Optional, Type, Union
 
 import dbt.flags as flags
 import yaml
+from dbt.adapters.factory import register_adapter
 from dbt.clients import yaml_helper  # type: ignore
 from dbt.config.profile import Profile, read_profile
 from dbt.config.project import PartialProject, Project
@@ -17,7 +19,8 @@ from dbt.config.renderer import DbtProjectYamlRenderer, ProfileRenderer
 from dbt.config.runtime import RuntimeConfig
 from dbt.contracts.graph.manifest import Manifest
 from dbt.graph.graph import Graph
-from dbt.task.base import BaseTask
+from dbt.helper_types import WarnErrorOptions
+from dbt.task.base import BaseTask, ConfiguredTask
 from dbt.task.build import BuildTask
 from dbt.task.clean import CleanTask
 from dbt.task.compile import CompileTask
@@ -26,18 +29,44 @@ from dbt.task.deps import DepsTask
 from dbt.task.freshness import FreshnessTask
 from dbt.task.generate import GenerateTask
 from dbt.task.list import ListTask
-from dbt.task.parse import ParseTask
 from dbt.task.run import RunTask
 from dbt.task.run_operation import RunOperationTask
+from dbt.task.runnable import GraphRunnableTask
 from dbt.task.seed import SeedTask
 from dbt.task.snapshot import SnapshotTask
 from dbt.task.test import TestTask
-from dbt.tracking import initialize_from_flags
+from dbt.tracking import initialize_from_flags as orig_initialize_from_flags
 
 from airflow_dbt_python.utils.enums import FromStrEnum, LogFormat, Output
+from airflow_dbt_python.utils.version import (
+    DBT_INSTALLED_GTE_1_5,
+    DBT_INSTALLED_GTE_1_7,
+    DBT_INSTALLED_LESS_THAN_1_5,
+)
 
-if TYPE_CHECKING:
-    from dbt.task.runnable import GraphRunnableTask
+if DBT_INSTALLED_LESS_THAN_1_5:
+    # dbt 1.5 removed the ParseTask as it only generated a manifest.
+    # This task is now handled by a simple function.
+    # Airflow-dbt-python should still support a ParseTask that does the same,
+    # but this will require writing our own ParseTask class.
+    # In the meantime, we treat ParseTask as CompileTask (which also generates
+    # a manifest) if running with dbt-core >= 1.5.
+    from dbt.task.parse import ParseTask  # type: ignore
+
+    # dbt 1.5 also changed the signature of initialize_from_flags, so we have
+    # this for backwards compatibility.
+    def initialize_from_flags(send_anonymous_usage_stats, profiles_dir):
+        """Call initialize_from_flags without arguments.
+
+        Added for backwards compatibility with versions of dbt < 1.5.
+        """
+        return orig_initialize_from_flags()  # type: ignore
+
+else:
+    from dbt.parser.manifest import ManifestLoader
+
+    ParseTask = CompileTask
+    initialize_from_flags = orig_initialize_from_flags
 
 
 def parse_yaml_args(args: Optional[Union[str, dict[str, Any]]]) -> dict[str, Any]:
@@ -78,16 +107,24 @@ class BaseConfig:
     single_threaded: Optional[bool] = None
     threads: Optional[int] = None
     use_experimental_parser: Optional[bool] = None
+    store_failures: Optional[bool] = None
     vars: Optional[Union[str, dict[str, Any]]] = None
+    macro_debugging: Optional[bool] = None
     warn_error: Optional[bool] = None
+    warn_error_options: dict[str, Any] = dataclasses.field(default_factory=dict)
+    indirect_selection: str = "eager"
 
     # Logging
     log_format: Optional[LogFormat] = None
-    log_cache_events: Optional[bool] = None
+    log_format_file: Optional[LogFormat] = None
+    log_path: Optional[str] = None if DBT_INSTALLED_LESS_THAN_1_5 else "logs"
+    log_level: str = "info"
+    log_level_file: str = "none"
     record_timing_info: Optional[str] = None
     debug: Optional[bool] = None
     quiet: Optional[bool] = None
     no_print: Optional[bool] = None
+    printer_width: Optional[int] = None
 
     # Mutually exclusive attributes
     defer: Optional[bool] = None
@@ -96,23 +133,62 @@ class BaseConfig:
     partial_parse: Optional[bool] = None
     no_partial_parse: Optional[bool] = dataclasses.field(default=None, repr=False)
 
+    log_cache_events: Optional[bool] = None
+    no_log_cache_events: Optional[bool] = dataclasses.field(default=None, repr=False)
+
     use_colors: Optional[bool] = None
     no_use_colors: Optional[bool] = dataclasses.field(default=None, repr=False)
 
+    use_colors_file: Optional[bool] = None
+    no_use_colors_file: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    introspect: Optional[bool] = None
+    no_introspect: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    populate_cache: Optional[bool] = None
+    no_populate_cache: Optional[bool] = dataclasses.field(default=None, repr=False)
+
     static_parser: Optional[bool] = None
     no_static_parser: Optional[bool] = dataclasses.field(default=None, repr=False)
 
     version_check: Optional[bool] = None
     no_version_check: Optional[bool] = dataclasses.field(default=None, repr=False)
 
-    send_anonymous_usage_stats: Optional[bool] = None
-    anonymous_usage_stats: Optional[bool] = dataclasses.field(default=None, repr=False)
+    # dbt < 1.5
+    anonymous_usage_stats: Optional[bool] = None
     no_anonymous_usage_stats: Optional[bool] = dataclasses.field(
         default=None, repr=False
     )
 
-    write_json: Optional[bool] = None
-    no_write_json: Optional[bool] = dataclasses.field(default=None, repr=False)
+    # dbt >= 1.5
+    if DBT_INSTALLED_GTE_1_5:
+        send_anonymous_usage_stats: Optional[bool] = None
+        no_send_anonymous_usage_stats: Optional[bool] = dataclasses.field(
+            default=None, repr=False
+        )
+
+        write_json: Optional[bool] = None
+        no_write_json: Optional[bool] = dataclasses.field(default=None, repr=False)
+
+    # dbt >= 1.7
+    if DBT_INSTALLED_GTE_1_7:
+        from dbt.cli.option_types import Package
+
+        include_saved_query: Optional[bool] = None
+        no_include_saved_query: Optional[bool] = dataclasses.field(
+            default=None, repr=False
+        )
+
+        clean_project_files_only: Optional[bool] = None
+        no_clean_project_files_only: Optional[bool] = dataclasses.field(
+            default=None, repr=False
+        )
+
+        add_package: Optional[Package] = None
+        dry_run: bool = False
+        lock: bool = False
+        static: bool = False
+        upgrade: bool = False
 
     def __post_init__(self):
         """Post initialization actions for a dbt configuration."""
@@ -121,6 +197,7 @@ class BaseConfig:
         self.set_mutually_exclusive_attributes()
 
         self.send_anonymous_usage_stats = self.anonymous_usage_stats
+        self.no_send_anonymous_usage_stats = self.no_anonymous_usage_stats
 
     def set_mutually_exclusive_attributes(self):
         """Support pairs of mutually exclusive parameters.
@@ -133,28 +210,82 @@ class BaseConfig:
                 to non-None values.
         """
         mutually_exclusive_attrs = (
-            "defer",
-            "partial_parse",
-            "use_colors",
-            "static_parser",
-            "version_check",
-            "anonymous_usage_stats",
-            "write_json",
+            ("defer", False),
+            ("partial_parse", True),
+            ("log_cache_events", False),
+            ("use_colors", True),
+            ("use_colors_file", True),
+            ("introspect", True),
+            ("populate_cache", True),
+            ("static_parser", True),
+            ("version_check", True),
+            ("anonymous_usage_stats", True),
+            ("send_anonymous_usage_stats", True),
+            ("write_json", True),
+            ("include_saved_query", None),
+            ("clean_project_files_only", True),
         )
 
-        for attr in mutually_exclusive_attrs:
-            positive_value = getattr(self, attr, None)
-            negative_value = getattr(self, f"no_{attr}", None)
+        for attrs, default_value in mutually_exclusive_attrs:
+            attr, negative_attr = attrs, f"no_{attrs}"
 
-            if positive_value is None and negative_value is None:
-                continue
+            positive_value = getattr(self, attr, None)
+            negative_value = getattr(self, negative_attr, None)
+
+            if (
+                positive_value is None
+                and negative_value is None
+                and default_value is not None
+            ):
+                setattr(self, attr, default_value)
+                setattr(self, negative_attr, not default_value)
             elif positive_value is not None and negative_value is not None:
-                raise ValueError(f"{attr} and no_{attr} are mutually exclusive")
+                raise ValueError(f"{attr} and {negative_attr} are mutually exclusive")
             elif positive_value is not None:
-                setattr(self, f"no_{attr}", not positive_value)
+                setattr(self, negative_attr, not positive_value)
             else:
                 setattr(self, attr, not negative_value)
 
+    def __getattribute__(self, item: str):
+        """Dbt 1.5+ uses uppercase attributes, let's handle this."""
+        if item.isupper():
+            item = item.lower()
+        return super().__getattribute__(item)
+
+    def to_flags(self) -> argparse.Namespace:
+        """Return a Namespace to use as dbt flags."""
+        flags_dict = vars(flags.get_flags())
+        flags_dict["MACRO_DEBUGGING"] = self.macro_debugging
+        flags_dict["WARN_ERROR"] = self.warn_error
+        flags_dict["WARN_ERROR_OPTIONS"] = WarnErrorOptions(
+            include=self.warn_error_options.get("include", []),
+            exclude=self.warn_error_options.get("exclude", []),
+        )
+
+        flags_dict["PRINTER_WIDTH"] = self.printer_width
+        flags_dict["TARGET_PATH"] = None
+        flags_dict["LOG_PATH"] = self.log_path
+        flags_dict["LOG_FORMAT"] = self.log_format
+        flags_dict["LOG_FORMAT_FILE"] = self.log_format
+        flags_dict["SEND_ANONYMOUS_USAGE_STATS"] = self.send_anonymous_usage_stats
+        flags_dict["PARTIAL_PARSE"] = self.partial_parse
+        flags_dict["STATIC_PARSER"] = self.static_parser
+        flags_dict["PROFILES_DIR"] = self.profiles_dir
+        flags_dict["STORE_FAILURES"] = self.store_failures
+        flags_dict["LOG_LEVEL"] = self.log_level
+        flags_dict["LOG_LEVEL_FILE"] = self.log_level_file
+        flags_dict["LOG_CACHE_EVENTS"] = self.log_cache_events
+        flags_dict["QUIET"] = self.quiet
+        flags_dict["DEBUG"] = self.debug
+        flags_dict["USE_COLORS_FILE"] = self.use_colors_file
+        flags_dict["WRITE_JSON"] = self.write_json
+        flags_dict["INDIRECT_SELECTION"] = getattr(self, "indirect_selection", None)
+        flags_dict["FAIL_FAST"] = self.fail_fast
+        flags_dict["INTROSPECT"] = self.introspect
+
+        flags_ns = argparse.Namespace(**flags_dict)
+        return flags_ns
+
     @property
     def dbt_task(self) -> Type[BaseTask]:
         """Access to the underlying dbt task class."""
@@ -228,7 +359,9 @@ class BaseConfig:
         task._runtime_initialize = _runtime_initialize  # type: ignore
 
     def create_dbt_task(
-        self, extra_targets: Optional[dict[str, Any]] = None
+        self,
+        extra_targets: Optional[dict[str, Any]] = None,
+        write_perf_info: bool = False,
     ) -> tuple[BaseTask, Optional[RuntimeConfig]]:
         """Create a dbt task given with this configuration.
 
@@ -237,23 +370,46 @@ class BaseConfig:
 
         Args:
             extra_targets: Additional targets for a dbt project's Profile.
+            write_perf_info: Flag to indicate whether to write performance info.
 
         Returns:
-            A tuple with the corresnponding subclass of a dbt BaseTask and the
+            A tuple with the corresponding subclass of a dbt BaseTask and the
             RuntimeConfig for the task.
         """
-        runtime_config = self.create_runtime_config(extra_targets)
-        task = self.dbt_task(args=self, config=runtime_config)
+        if not DBT_INSTALLED_LESS_THAN_1_5:
+            local_flags = self.to_flags()
+            flags.set_flags(local_flags)
+
+        project, profile = self.create_dbt_project_and_profile(extra_targets)
+        runtime_config = self.create_runtime_config(project, profile)
+
+        if not DBT_INSTALLED_LESS_THAN_1_5:
+            if issubclass(self.dbt_task, ConfiguredTask) and runtime_config:
+                register_adapter(runtime_config)
+                manifest = ManifestLoader.get_full_manifest(
+                    runtime_config, write_perf_info=write_perf_info
+                )
+                task: BaseTask = self.dbt_task(
+                    args=self, config=runtime_config, manifest=manifest
+                )
+            elif issubclass(self.dbt_task, DepsTask):
+                task = self.dbt_task(args=self, project=project)
+            elif issubclass(self.dbt_task, DebugTask):
+                task = self.dbt_task(args=self, config=runtime_config)
+            else:
+                task = self.dbt_task(args=self, config=runtime_config, project=project)
+        else:
+            task = self.dbt_task(args=self, config=runtime_config)
 
         if self.compiled_target is not None:
             # Only supported by subclasses of dbt's GraphRunnableTask.
             # Represented here by the presence of the compiled_target attribute.
             self.patch_manifest_task(task)  # type: ignore
 
-        return (task, runtime_config)
+        return task, runtime_config
 
     def create_runtime_config(
-        self, extra_targets: Optional[dict[str, Any]]
+        self, project: Project, profile: Profile
     ) -> Optional[RuntimeConfig]:
         """Crete a dbt RuntimeConfig, if possible.
 
@@ -262,19 +418,21 @@ class BaseConfig:
         Flags are also initialized as configuration is created.
 
         Args:
-            extra_targets: Additional targets for a dbt project's Profile.
+            project: dbt project.
+            profile: dbt profile.
 
         Returns:
             A RuntimeConfig instance.
         """
-        project, profile = self.create_dbt_project_and_profile(extra_targets)
-        initialize_from_flags()
+        initialize_from_flags(self.send_anonymous_usage_stats, self.profiles_dir)
         self.cls.set_log_format()
-        flags.set_from_args(self, profile.user_config)
+        flags.set_from_args(self, profile.user_config)  # type: ignore
 
         cfg_type = self.dbt_task.ConfigType
 
         if issubclass(cfg_type, RuntimeConfig):
+            if not DBT_INSTALLED_LESS_THAN_1_5 and isinstance(self.vars, str):
+                self.vars = yaml.safe_load(self.vars)
             return cfg_type.from_parts(project=project, profile=profile, args=self)
         return None
 
@@ -295,11 +453,11 @@ class BaseConfig:
         project = Project.from_project_root(
             self.project_dir or ".",
             project_renderer,
-            verify_version=bool(flags.VERSION_CHECK),
+            verify_version=bool(getattr(self, "version_check", True)),
         )
         project.project_env_vars = project_renderer.ctx_obj.env_vars
 
-        return (project, profile)
+        return project, profile
 
     @property
     def profile_name(self) -> str:
@@ -336,8 +494,8 @@ class BaseConfig:
             A PartialProject instance for this configuration.
         """
         project_root = self.project_dir if self.project_dir else os.getcwd()
-        version_check = bool(flags.VERSION_CHECK)
-        partial_project = Project.partial_load(
+        version_check = bool(getattr(self, "version_check", True))
+        partial_project = PartialProject.from_project_root(
             project_root, verify_version=version_check
         )
 
@@ -390,7 +548,9 @@ class SelectionConfig(BaseConfig):
     exclude: Optional[list[str]] = None
     select: Optional[list[str]] = None
     selector_name: Optional[list[str]] = None
+    selector: Optional[str] = None
     state: Optional[Union[Path, str]] = None
+    defer_state: Optional[Union[Path, str]] = None
 
     # Kept for compatibility with dbt versions < 0.21
     models: Optional[list[str]] = None
@@ -400,6 +560,8 @@ class SelectionConfig(BaseConfig):
         super().__post_init__()
         if isinstance(self.state, str):
             self.state = Path(self.state)
+        if isinstance(self.defer_state, str):
+            self.defer_state = Path(self.defer_state)
 
 
 @dataclasses.dataclass
@@ -419,7 +581,6 @@ class BuildTaskConfig(TableMutabilityConfig):
 
     cls: Type[BaseTask] = dataclasses.field(default=BuildTask, init=False)
     singular: Optional[bool] = None
-    indirect_selection: Optional[str] = None
     resource_types: Optional[list[str]] = None
     generic: Optional[bool] = None
     show: Optional[bool] = None
@@ -466,6 +627,7 @@ class DebugTaskConfig(BaseConfig):
 
     cls: Type[BaseTask] = dataclasses.field(default=DebugTask, init=False)
     config_dir: Optional[bool] = None
+    connection: Optional[bool] = None
     which: str = dataclasses.field(default="debug", init=False)
 
 
@@ -483,6 +645,7 @@ class GenerateTaskConfig(SelectionConfig):
 
     cls: Type[BaseTask] = dataclasses.field(default=GenerateTask, init=False)
     compile: bool = True
+    empty_catalog: bool = False
     which: str = dataclasses.field(default="generate", init=False)
 
 
@@ -491,7 +654,7 @@ class ListTaskConfig(SelectionConfig):
     """Dbt list task arguments."""
 
     cls: Type[BaseTask] = dataclasses.field(default=ListTask, init=False)
-    indirect_selection: Optional[str] = None
+    indirect_selection: str = "eager"
     output: Output = Output.SELECTOR
     output_keys: Optional[list[str]] = None
     resource_types: Optional[list[str]] = None
@@ -499,8 +662,11 @@ class ListTaskConfig(SelectionConfig):
 
 
 @dataclasses.dataclass
-class ParseTaskConfig(BaseConfig):
-    """Dbt parse task arguments."""
+class ParseTaskConfig(SelectionConfig):
+    """Dbt parse task arguments.
+
+    TODO: Temporarily, handle this as a CompileTask.
+    """
 
     cls: Type[BaseTask] = dataclasses.field(default=ParseTask, init=False)
     compile: Optional[bool] = None
@@ -520,7 +686,7 @@ class RunTaskConfig(TableMutabilityConfig):
 class RunOperationTaskConfig(BaseConfig):
     """Dbt run-operation task arguments."""
 
-    args: str = "{}"
+    args: dict[str, Any] | str = dataclasses.field(default_factory=dict)
     cls: Type[BaseTask] = dataclasses.field(default=RunOperationTask, init=False)
     macro: Optional[str] = None
     which: str = dataclasses.field(default="run-operation", init=False)
@@ -528,7 +694,8 @@ class RunOperationTaskConfig(BaseConfig):
     def __post_init__(self):
         """Support dictionary args by casting them to str after setting."""
         super().__post_init__()
-        self.args = str(self.args)
+        if DBT_INSTALLED_LESS_THAN_1_5:
+            self.args = str(self.args)
 
 
 @dataclasses.dataclass
@@ -563,7 +730,7 @@ class TestTaskConfig(SelectionConfig):
 
     cls: Type[BaseTask] = dataclasses.field(default=TestTask, init=False)
     generic: Optional[bool] = None
-    indirect_selection: Optional[str] = None
+    indirect_selection: str = "eager"
     singular: Optional[bool] = None
     store_failures: Optional[bool] = None
     which: str = dataclasses.field(default="test", init=False)
